@@ -1,4 +1,3 @@
-from hdx.location.adminone import AdminOne
 from hdx.utilities.dateparse import parse_date
 
 from hdx.scraper.base_scraper import BaseScraper
@@ -18,18 +17,17 @@ class TestScrapersRegionalToplevel:
     def test_regionaltoplevel(self, configuration, fallbacks):
         BaseScraper.population_lookup = dict()
         today = parse_date("2020-10-01")
-        adminone = AdminOne(configuration)
 
         level = "national"
         scraper_configuration = configuration[f"scraper_{level}"]
         iso3s = ("AFG", "MMR")
-        runner = Runner(iso3s, adminone, today)
+        runner = Runner(iso3s, today)
         runner.add_configurables(scraper_configuration, level)
 
         level = "national"
         BaseScraper.population_lookup = dict()
         iso3s = ("AFG", "PSE")
-        runner = Runner(iso3s, adminone, today)
+        runner = Runner(iso3s, today)
         runner.add_configurables(scraper_configuration, level)
 
         names = ("population", "who_national")
